import os
import yaml

import flask
from lpreports.launchpad import filters


def get_report_by_name(name):
    app = flask.current_app
    reports = app.config['REPORT_CONFIG']['reports']
    for report in reports:
        if report['name'] == name:
            return report

    return None


def set_defaults(report, defaults):
    for key in defaults:
        if key not in report:
            report[key] = defaults[key]
        else:
            if isinstance(defaults[key], dict):
                set_defaults(report[key], defaults[key])


def read_config_file():
    dir_name = os.path.dirname(os.path.abspath(__file__))
    config_path = os.path.join(dir_name, "../", "config", "reports.yaml")
    with open(config_path, 'r') as stream:
        config = yaml.load(stream)

    defaults = config['report-default-values']

    for report in config['reports']:
        set_defaults(report, defaults)

    return config


def filter_bugs(request, bugs, teams_data):
    search_params = {
        'target_name': request.args.get('project'),
        'milestone': request.args.getlist('milestone'),
        'status': request.args.getlist('status'),
        'importance': request.args.getlist('importance'),
        'reporter': request.args.getlist('reporter'),
        'assignee': request.args.getlist('assignee'),
        'assigned_person': request.args.getlist('assigned_person'),
        'verifier': request.args.getlist('verifier'),
        'criteria': request.args.getlist('criteria'),
        'tags': request.args.getlist('tags'),
        'exclude_tags': request.args.getlist('exclude_tags'),
        'created_from': request.args.get('created_from'),
        'created_to': request.args.get('created_to'),
        'triaged_from': request.args.get('triaged_from'),
        'triaged_to': request.args.get('triaged_to'),
        'fix_committed_from': request.args.get('fix_committed_from'),
        'fix_committed_to': request.args.get('fix_committed_to'),
        'fix_released_from': request.args.get('fix_released_from'),
        'fix_released_to': request.args.get('fix_released_to'),
    }

    bugs = filters.filter_bugs(bugs, search_params, teams_data)

    return bugs, search_params
